@@ -53,7 +53,6 @@
 #include <shellapi.h>
 #endif
 
-#define GLADE_UTIL_SELECTION_NODE_SIZE 7
 #define GLADE_UTIL_COPY_BUFFSIZE       1024
 
 
@@ -564,79 +563,6 @@ glade_util_duplicate_underscores (const gchar * name)
   return underscored_name;
 }
 
-static void
-glade_util_draw_nodes (cairo_t * cr, GdkColor * color,
-                       gint x, gint y, gint width, gint height)
-{
-  if (width > GLADE_UTIL_SELECTION_NODE_SIZE &&
-      height > GLADE_UTIL_SELECTION_NODE_SIZE)
-    {
-      glade_utils_cairo_draw_rectangle (cr, color, TRUE,
-                                        x, y,
-                                        GLADE_UTIL_SELECTION_NODE_SIZE,
-                                        GLADE_UTIL_SELECTION_NODE_SIZE);
-      glade_utils_cairo_draw_rectangle (cr, color, TRUE,
-                                        x,
-                                        y + height -
-                                        GLADE_UTIL_SELECTION_NODE_SIZE,
-                                        GLADE_UTIL_SELECTION_NODE_SIZE,
-                                        GLADE_UTIL_SELECTION_NODE_SIZE);
-      glade_utils_cairo_draw_rectangle (cr, color, TRUE,
-                                        x + width -
-                                        GLADE_UTIL_SELECTION_NODE_SIZE, y,
-                                        GLADE_UTIL_SELECTION_NODE_SIZE,
-                                        GLADE_UTIL_SELECTION_NODE_SIZE);
-      glade_utils_cairo_draw_rectangle (cr, color, TRUE,
-                                        x + width -
-                                        GLADE_UTIL_SELECTION_NODE_SIZE,
-                                        y + height -
-                                        GLADE_UTIL_SELECTION_NODE_SIZE,
-                                        GLADE_UTIL_SELECTION_NODE_SIZE,
-                                        GLADE_UTIL_SELECTION_NODE_SIZE);
-    }
-
-  glade_utils_cairo_draw_rectangle (cr, color, FALSE, x, y, width - 1,
-                                    height - 1);
-}
-
-/**
- * glade_util_draw_selection_nodes:
- * @widget: a #GtkWidget
- * @cr: the #cairo_t to draw with
- *
- * Draws selection on @widget if @widget is selected.
- */
-void
-glade_util_draw_selection_nodes (GtkWidget * widget, cairo_t * cr)
-{
-  GladeWidget *gwidget;
-  GladeProject *project;
-  GdkColor *color;
-  GtkAllocation allocation;
-
-  g_return_if_fail (GTK_IS_WIDGET (widget));
-  
-  gwidget = glade_widget_get_from_gobject (widget);
-  if (!gwidget)
-    return;
-
-  project = glade_widget_get_project (gwidget);
-  g_return_if_fail (GLADE_IS_PROJECT (project));
-
-  if (!glade_project_is_selected (project, G_OBJECT (widget)))
-    return;
-
-  cairo_save (cr);
-
-  color = &(gtk_widget_get_style (widget)->black);
-
-  gtk_widget_get_allocation (widget, &allocation);
-  glade_util_draw_nodes (cr, color,
-			 0, 0, allocation.width, allocation.height);
-
-  cairo_restore (cr);
-}
-
 /*
  * taken from gtk... maybe someday we can convince them to
  * expose gtk_container_get_all_children
@@ -882,7 +808,10 @@ glade_util_canonical_path (const gchar * path)
           if (g_chdir (dirname) == 0)
             {
               if ((direct_dir = g_get_current_dir ()) != NULL)
-                direct_name = g_build_filename (direct_dir, basename, NULL);
+		{
+		  direct_name = g_build_filename (direct_dir, basename, NULL);
+		  g_free (direct_dir);
+		}
               else
                 g_warning ("g_path");
 
@@ -1354,10 +1283,9 @@ glade_utils_enum_value_from_string (GType enum_type, const gchar * strval)
   if (((displayable =
         glade_get_value_from_displayable (enum_type, strval)) != NULL &&
        (gvalue =
-        glade_utils_value_from_string (enum_type, displayable, NULL,
-                                       NULL)) != NULL) ||
+        glade_utils_value_from_string (enum_type, displayable, NULL)) != NULL) ||
       (gvalue =
-       glade_utils_value_from_string (enum_type, strval, NULL, NULL)) != NULL)
+       glade_utils_value_from_string (enum_type, strval, NULL)) != NULL)
     {
       value = g_value_get_enum (gvalue);
       g_value_unset (gvalue);
@@ -1417,10 +1345,9 @@ glade_utils_flags_value_from_string (GType flags_type, const gchar * strval)
   if (((displayable =
         glade_get_value_from_displayable (flags_type, strval)) != NULL &&
        (gvalue =
-        glade_utils_value_from_string (flags_type, displayable, NULL,
-                                       NULL)) != NULL) ||
+        glade_utils_value_from_string (flags_type, displayable, NULL)) != NULL) ||
       (gvalue =
-       glade_utils_value_from_string (flags_type, strval, NULL, NULL)) != NULL)
+       glade_utils_value_from_string (flags_type, strval, NULL)) != NULL)
     {
       value = g_value_get_flags (gvalue);
       g_value_unset (gvalue);
@@ -1609,7 +1536,7 @@ pclass_from_gtype (GType type)
 GValue *
 glade_utils_value_from_string (GType type,
                                const gchar * string,
-                               GladeProject * project, GladeWidget * widget)
+                               GladeProject * project)
 {
   GladePropertyClass *pclass;
 
@@ -1617,8 +1544,7 @@ glade_utils_value_from_string (GType type,
   g_return_val_if_fail (string != NULL, NULL);
 
   if ((pclass = pclass_from_gtype (type)) != NULL)
-    return glade_property_class_make_gvalue_from_string (pclass, string,
-                                                         project, widget);
+    return glade_property_class_make_gvalue_from_string (pclass, string, project);
 
   return NULL;
 }
